@@ -261,7 +261,7 @@ class Hourly(Base):
         if method == 'nearest':
 
             self._data = self._data.groupby(
-                pd.Grouper(level='time', freq='1H')).agg('first')
+                pd.Grouper(level='time', freq=self._freq)).agg('first')
 
         else:
 
@@ -279,11 +279,11 @@ class Hourly(Base):
             # Exclude non-mean data & perform aggregation
             excluded = data[['wdir', 'coco']]
             excluded = excluded.groupby(
-                pd.Grouper(level='time', freq='1H')).agg('first')
+                pd.Grouper(level='time', freq=self._freq)).agg('first')
 
             # Aggregate mean data
             data = data.groupby(
-                pd.Grouper(level='time', freq='1H')).apply(weighted_average)
+                pd.Grouper(level='time', freq=self._freq)).apply(weighted_average)
 
             # Drop RangeIndex
             data.index = data.index.droplevel(1)
