@@ -193,7 +193,7 @@ class Monthly(Base):
         if method == 'nearest':
 
             self._data = self._data.groupby(
-                pd.Grouper(level='time', freq='1D')).agg('first')
+                pd.Grouper(level='time', freq=self._freq)).agg('first')
 
         else:
 
@@ -213,11 +213,11 @@ class Monthly(Base):
             # Exclude non-mean data & perform aggregation
             excluded = data['wdir']
             excluded = excluded.groupby(
-                pd.Grouper(level='time', freq='1D')).agg('first')
+                pd.Grouper(level='time', freq=self._freq)).agg('first')
 
             # Aggregate mean data
             data = data.groupby(
-                pd.Grouper(level='time', freq='1D')).apply(weighted_average)
+                pd.Grouper(level='time', freq=self._freq)).apply(weighted_average)
 
             # Drop RangeIndex
             data.index = data.index.droplevel(1)
@@ -255,7 +255,7 @@ class Monthly(Base):
             self._stations = pd.Index(loc)
 
         # Set start date
-        self._start = start
+        self._start = start.replace(day=1)
 
         # Set end date
         self._end = end
